
/*********************************************************

INCLUDE FILE: screenshot.agc
  by Steve Vink, May 2015
  Use permitted for all purposes, commercial and personal

	This file contains functions to facilitate taking screenshots

// Project: Screenshots
// Created: 2015-05-25


**********************************************************/

// Constants for the state of the Screenshot module
#constant cSTATE_SCREENSHOT_IDLE = 10
#constant cSTATE_SCREENSHOT_GRAB = 20
#constant cSTATE_SCREENSHOT_SAVE = 30
#constant cSTATE_SCREENSHOT_RESET = 40

type tScreenShot
	state as integer
	delay as float
	count as integer
	currentTime as float
	currentCount as integer
	interval as float
	imageID as integer
	id as integer
	name as string
	sound as integer
endtype

global gScreenShot as tScreenShot

//*********************************************************
function initScreenShot()
//*********************************************************
//
//	Initialise the screenshot system. Call this at the beginning of 
//	the program
//
//	Set State to idle
//	Set Delay to -1
//	set Count to 1	(default Value)
//	Set Time to -1 (do not take screenshot)
//	set interval to 1 second (default Value)
//	set ID to 1 (File suffix)
//	set name to "screenshot" (Default)
//*********************************************************
	
	gScreenShot.state = cSTATE_SCREENSHOT_IDLE
	gScreenShot.delay = 0
	gScreenShot.count = 1
	gScreenShot.currentTime = -1
	gScreenShot.interval = 1
	gScreenShot.id = 1
	gScreenShot.name = "Screenshot"
	
endfunction


//*********************************************************
function ScreenShotProcess()
//*********************************************************
//	Process the screenshot
//	This is a multi-part process to reduce game stutter
//	Step 1 - Trigger process
//	Step 2 - Grab screen
//	Step 3 - Save file
//	Step 4 - Reset
//*********************************************************

	select gScreenShot.state
		
		// Trigger the process
		case cSTATE_SCREENSHOT_IDLE
			gScreenShot.currentTime = Timer() + gScreenShot.delay
			gScreenShot.state = cSTATE_SCREENSHOT_GRAB
		endcase
		
		//Grab the screenshot
		case cSTATE_SCREENSHOT_GRAB
			if timer() > gScreenShot.currentTime
				// If a sound has been set, the sound id will be > 0
				render()
				gScreenShot.imageID = GetImage(0,0,GetVirtualWidth(), GetVirtualHeight())
				ClearScreen()
				gScreenShot.state = cSTATE_SCREENSHOT_SAVE
				if gScreenShot.sound > 0
					null = PlaySound(gScreenShot.sound)
				endif
			endif
		endcase
		
		//Save the screenshot
		case cSTATE_SCREENSHOT_SAVE
			file$ = gScreenShot.name + "_" + str(gScreenShot.id) + ".jpg"
			if GetFileExists(file$)
				DeleteFile(file$)
			endif
			SaveImage(gScreenShot.imageID,file$)
			gScreenShot.state = cSTATE_SCREENSHOT_RESET
		endcase
		
		//Reset
		case cSTATE_SCREENSHOT_RESET
			DeleteImage(gScreenShot.imageID)
			inc gScreenShot.id, 1
			inc gScreenShot.currentCount, 1
			// If multiple shots requested, take another after specified interval
			if gScreenShot.currentCount < gScreenShot.count
				gScreenShot.currentTime = timer() + gScreenShot.interval
				gScreenShot.state = cSTATE_SCREENSHOT_GRAB
			else
				gScreenShot.currentTime = -1
				gScreenShot.currentCount = 0
				gScreenShot.state = cSTATE_SCREENSHOT_IDLE
			endif
		endcase
		
	endselect

endfunction


//*********************************************************
function ScreenShotSetCount(count as integer)
//*********************************************************
//	Setup function - set the number of shots to take
//	This allows more than one screenshot to be taken 
//	in one set
//*********************************************************

	gScreenShot.count = count

endfunction

//*********************************************************
function ScreenShotSetDelay(delay as float)
//*********************************************************
//	Setup function - set the delay after requesting screenshot
//*********************************************************

	gScreenShot.delay = delay

endfunction

//*********************************************************
function ScreenShotSetInterval(interval as float)
//*********************************************************
//	Setup function - set the interval between successive shots
//*********************************************************

	gScreenShot.interval = interval

endfunction

//*********************************************************
function ScreenShotSetName(name as string)
//*********************************************************
//	Setup function - set the name of the saved file
//*********************************************************

	gScreenShot.name = name

endfunction

//*********************************************************
function ScreenShotSetSound(id as integer)
//*********************************************************
//	Setup function - set the id of a sound to play
//*********************************************************

	gScreenShot.sound=id

endfunction
